<?php
/**
 * Footer options
 *
 * @package Theme Palace
 * @subpackage Yummy Pro
 * @since Yummy Pro 1.0
 */

/*Footer Section*/
$wp_customize->add_section( 'yummy_pro_section_footer', array(
	'title'      			=> esc_html__( 'Footer Options', 'yummy-pro' ),
	'panel'      			=> 'yummy_pro_theme_options_panel',
) );

// Footer Enable Options
$wp_customize->add_setting( 'yummy_pro_theme_options[enable_footer]', array(
	'default'           => $options['enable_footer'],
	'sanitize_callback' => 'yummy_pro_sanitize_select',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[enable_footer]', array(
	'label'               => esc_html__( 'Enable Footer On', 'yummy-pro' ),
	'description'		  => esc_html__( 'This options enable footer on entire site or only on static front page.','yummy-pro' ), 
	'section'             => 'yummy_pro_section_footer',
	'type'                => 'select',
	'choices'			  => array(
		'static-front-page'	=> esc_html__( 'Static Front Page','yummy-pro' ),
		'entire-site'		=> esc_html__( 'Entire Site','yummy-pro' ),	
	),
) );

// Image Options
$wp_customize->add_setting( 'yummy_pro_theme_options[footer_background_image]', array(
	'default'           => $options['footer_background_image'],
	'sanitize_callback' => 'yummy_pro_sanitize_image',
) );

$wp_customize->add_control( new WP_Customize_Image_Control(  $wp_customize, 'yummy_pro_theme_options[footer_background_image]', array(
	'label'           => esc_html__( 'Footer Background Image ', 'yummy-pro' ),
	'description'	  => esc_html__( 'Preferred size is 1920px by 1080px','yummy-pro' ),
	'section'         => 'yummy_pro_section_footer',	
) ) );

// Copyright text setting and control.
$wp_customize->add_setting( 'yummy_pro_theme_options[copyright_text]', array(
	'sanitize_callback'   => 'wp_kses_post',
	'default'             => $options['copyright_text'],
	'transport'			  => 'postMessage',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[copyright_text]', array(
	'label'               => esc_html__( 'Copyright', 'yummy-pro' ),
	'section'             => 'yummy_pro_section_footer',
	'type'                => 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'yummy_pro_theme_options[copyright_text]', array(
		'selector'            => '#colophon .wrapper .site-info span.copyright',
		'settings'            => 'yummy_pro_theme_options[copyright_text]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'yummy_pro_copyright_text_callback',
    ) );
}

// Powered by text setting and control.
$wp_customize->add_setting( 'yummy_pro_theme_options[powered_by]', array(
	'sanitize_callback'   => 'wp_kses_post',
	'default'             => $options['powered_by'],
	'transport'			  => 'postMessage',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[powered_by]', array(
	'label'               => esc_html__( 'Powered By Text', 'yummy-pro' ),
	'section'             => 'yummy_pro_section_footer',
	'type'                => 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'yummy_pro_theme_options[powered_by]', array(
		'selector'            => '#colophon .wrapper .site-info span.powered',
		'settings'            => 'yummy_pro_theme_options[powered_by]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'yummy_pro_powered_by_callback',
    ) );
}

// Copyright Background Image Options
$wp_customize->add_setting( 'yummy_pro_theme_options[copyright_background_image]', array(
	'default'           => $options['copyright_background_image'],
	'sanitize_callback' => 'yummy_pro_sanitize_image',
) );

$wp_customize->add_control( new WP_Customize_Image_Control(  $wp_customize, 'yummy_pro_theme_options[copyright_background_image]', array(
	'label'           => esc_html__( 'Copyright Background Image ', 'yummy-pro' ),
	'description'	  => esc_html__( 'Preferred size is 1920px by 1080px','yummy-pro' ),
	'section'         => 'yummy_pro_section_footer',	
) ) );

// Scroll top visible
$wp_customize->add_setting( 'yummy_pro_theme_options[scroll_top_visible]', array(
		'default'       		=> $options['scroll_top_visible'],
		'sanitize_callback'		=> 'yummy_pro_sanitize_checkbox',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[scroll_top_visible]', array(
		'label'      			=> esc_html__( 'Display Scroll Top Button', 'yummy-pro' ),
		'section'    			=> 'yummy_pro_section_footer',
		'type'		 			=> 'checkbox',
) );
